SimulatedMacBridge

Struct SimulatedMacBridge 

pub struct SimulatedMacBridge { /* private fields */ }
Hermetic simulated Mac bridge driver for tests and non-Mac host environments.

Implementations

Source

impl SimulatedMacBridge

pub fn new() -> Self

Create a new simulated bridge driver.

pub fn new_failing() -> Self

Create a simulated bridge driver that fails simulated foreign calls (for error testing).