pub struct SelectionRect {
pub x: f32,
pub y: f32,
pub width: f32,
pub height: f32,
}Expand description
A visual selection rectangle covering a contiguous visual portion of a selection.
Plan 13.6: “Selection rectangles may cover discontiguous visual runs for one logical range.”
Fields
x: f32Visual X coordinate of the left edge.
y: f32Visual Y coordinate of the top edge.
width: f32Width of this selection slice.
height: f32Height of this selection slice.