pub struct SimulatedMacBridge { /* private fields */ }Expand description
Hermetic simulated Mac bridge driver for tests and non-Mac host environments.
Implementations
Sourceimpl SimulatedMacBridge
impl SimulatedMacBridge
Sourcepub fn new_failing() -> Self
pub fn new_failing() -> Self
Create a simulated bridge driver that fails simulated foreign calls (for error testing).